package com.yunzhi.marketing.redpack.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.redpack.entity.TaMpPerson;
import com.yunzhi.marketing.redpack.service.ITaMpPersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 公众号用户表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-06-02
 */
@RestController
@RequestMapping("/")
public class TaMpPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMpPersonController.class);

    @Autowired
    public ITaMpPersonService iTaMpPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taMpPerson",method= RequestMethod.GET)
    public ResponseBean taMpPersonList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaMpPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaMpPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaMpPerson> result = iTaMpPersonService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMpPersonList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taMpPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taMpPerson",method= RequestMethod.POST)
    public ResponseBean taMpPersonAdd(@RequestBody TaMpPerson taMpPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaMpPersonService.save(taMpPerson)){
                responseBean.addSuccess(taMpPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMpPersonAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taMpPerson/{id}", method= RequestMethod.DELETE)
    public ResponseBean taMpPersonDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaMpPersonService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMpPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMpPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taMpPerson/{id}",method= RequestMethod.PUT)
    public ResponseBean taMpPersonUpdate(@PathVariable Integer id,
                                        @RequestBody TaMpPerson taMpPerson){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaMpPersonService.updateById(taMpPerson)){
                responseBean.addSuccess(taMpPerson);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMpPersonUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taMpPerson/{id}",method= RequestMethod.GET)
    public ResponseBean taMpPersonGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaMpPersonService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taMpPersonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
